@@ -1,5 +1,6 @@
 /*  Arg_parser - POSIX/GNU command line argument parser. (C++ version)
-    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Antonio Diaz Diaz.
+    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012
+    Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,7 +35,7 @@ namespace {
 
 const char * const Program_name = "Arg_parser";
 const char * const program_name = "arg_parser";
-const char * const program_year = "2011";
+const char * const program_year = "2012";
 const char * invocation_name = 0;
 
 
@@ -42,25 +43,25 @@ void show_help( const bool verbose )
   {
   std::printf( "%s - POSIX/GNU command line argument parser. (C++ version)\n", Program_name );
   std::printf( "See the source file `main.cc' to learn how to use %s in\n", Program_name );
-  std::printf( "your own programs.\n" );
-  std::printf( "\nUsage: %s [options]\n", invocation_name );
-  std::printf( "\nOptions:\n" );
-  std::printf( "  -h, --help                   display this help and exit\n" );
-  std::printf( "  -V, --version                output version information and exit\n" );
-  std::printf( "  -a, --append                 example of option with no argument\n" );
-  std::printf( "  -b, --block=<arg>            example of option with required argument\n" );
-  std::printf( "  -c, --casual[=<arg>]         example of option with optional argument\n" );
-  std::printf( "  -o <arg>                     example of short only option\n" );
-  std::printf( "      --orphan                 example of long only option\n" );
-  std::printf( "  -q, --quiet                  quiet operation\n" );
-  std::printf( "  -u, --uncaught               example of intentional bug\n" );
-  std::printf( "  -v, --verbose                verbose operation\n" );
+  std::printf( "your own programs.\n"
+               "\nUsage: %s [options]\n", invocation_name );
+  std::printf( "\nOptions:\n"
+               "  -h, --help                   display this help and exit\n"
+               "  -V, --version                output version information and exit\n"
+               "  -a, --append                 example of option with no argument\n"
+               "  -b, --block=<arg>            example of option with required argument\n"
+               "  -c, --casual[=<arg>]         example of option with optional argument\n"
+               "  -o <arg>                     example of short only option\n"
+               "      --orphan                 example of long only option\n"
+               "  -q, --quiet                  quiet operation\n"
+               "  -u, --uncaught               example of intentional bug\n"
+               "  -v, --verbose                verbose operation\n" );
   if( verbose )
     {
     std::printf( "  -H, --hidden                 example of hidden option (shown with -v -h)\n" );
     }
-  std::printf( "\nReport bugs to bug-moe@gnu.org\n");
-  std::printf( "Arg_parser home page: http://www.nongnu.org/arg-parser/arg_parser.html\n" );
+  std::printf( "\nReport bugs to bug-moe@gnu.org\n"
+               "Arg_parser home page: http://www.nongnu.org/arg-parser/arg_parser.html\n" );
   }
 
 
@@ -68,13 +69,14 @@ void show_version()
   {
   std::printf( "%s %s\n", Program_name, PROGVERSION );
   std::printf( "Copyright (C) %s Antonio Diaz Diaz.\n", program_year );
-  std::printf( "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n" );
-  std::printf( "This is free software: you are free to change and redistribute it.\n" );
-  std::printf( "There is NO WARRANTY, to the extent permitted by law.\n" );
+  std::printf( "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n"
+               "This is free software: you are free to change and redistribute it.\n"
+               "There is NO WARRANTY, to the extent permitted by law.\n" );
   }
 
 
-void show_error( const char * const msg, const int errcode = 0, const bool help = false )
+void show_error( const char * const msg, const int errcode = 0,
+                 const bool help = false )
   {
   if( msg && msg[0] )
     {
@@ -89,7 +91,7 @@ void show_error( const char * const msg, const int errcode = 0, const bool help
   }
 
 
-void internal_error( const char * const msg )
+void internal_error( const char * const msg ) throw()
   {
   std::fprintf( stderr, "%s: internal error: %s.\n", program_name, msg );
   std::exit( 3 );
@@ -111,7 +113,7 @@ const char * optname( const int code, const Arg_parser::Option options[] )
 } // end namespace
 
 
-int main( const int argc, const char * argv[] )
+int main( const int argc, const char * const argv[] )
   {
   bool verbose = false;
   invocation_name = argv[0];
