@@ -24,27 +24,28 @@ fi
 
 if [ -d tmp ] ; then rm -rf tmp ; fi
 mkdir tmp
-printf "testing arg_parser-%s..." "$2"
 cd "${objdir}"/tmp
 
-cat "${testdir}"/test.txt > in || framework_failure
+in="${testdir}"/test.txt
 fail=0
 
+printf "testing arg_parser-%s..." "$2"
+
 for i in "${PARSER}" "${CPARSER}" ; do
 	"$i" -a -b 5 -c -carg -o file --orphan file1 file2 > out || fail=1
-	cmp in out || fail=1
+	cmp ${in} out || fail=1
 	printf .
 
 	"$i" -ab5 -c -carg -ofile file1 --orphan file2 > out || fail=1
-	cmp in out || fail=1
+	cmp ${in} out || fail=1
 	printf .
 
 	"$i" --append file1 --block 5 --casual file2 --casual=arg -o file --orphan > out || fail=1
-	cmp in out || fail=1
+	cmp ${in} out || fail=1
 	printf .
 
 	"$i" --append --block=5 --casual= file1 --casual=arg -ofile --orphan file2 > out || fail=1
-	cmp in out || fail=1
+	cmp ${in} out || fail=1
 	printf .
 
 	"$i" -aARG 2>/dev/null
